#include "commandswidget.h"
#include "mimefactory.h"
#include <qpushbutton.h>
#include <qfileinfo.h>


CommandsWidget::CommandsWidget ( QWidget * parent, const char * name, WFlags flags )
	: QHBox ( parent, name, flags )
	, m_help ( NULL )
	, m_quit ( NULL )
	, m_go ( NULL )
	, m_filesSelected ( 0 )
	, m_outputDirValid ( true )
{
	setMargin ( 0 );
	setSpacing ( 5 );

	// Create the buttons
	m_quit = new QPushButton ( "Quit", this );
	m_help = new QPushButton ( "Help", this );
	m_go = new QPushButton ( "Go", this );

	// Setup the signalling
	connect ( m_quit, SIGNAL ( clicked ( ) ), this, SIGNAL ( Quit ( ) ) );
	connect ( m_go, SIGNAL ( clicked ( ) ), this, SIGNAL ( Go ( ) ) );
	connect ( m_help, SIGNAL ( clicked ( ) ), this, SIGNAL ( Help ( ) ) );

	// Disable the help button if the MimeFactory isn't valid
	m_help->setEnabled ( TheMimeFactory ( ).IsValid ( ) );
	
	// Setup the go button
	UpdateGoButton ( );
}


void CommandsWidget::NewOutputDir ( const QString & dir )
{
	m_outputDirValid = IsDirectory ( dir );
	UpdateGoButton ( );
}


void CommandsWidget::FileSelectionChanged ( unsigned int numberOfFiles )
{
	m_filesSelected = numberOfFiles;
	UpdateGoButton ( );
}


bool CommandsWidget::IsDirectory ( const QString & dir )
{
	QFileInfo dirInfo ( dir );
	return dirInfo.exists ( ) && dirInfo.isDir ( ) && dirInfo.isWritable ( );
}


void CommandsWidget::UpdateGoButton ( )
{
	m_go->setEnabled ( ( m_filesSelected > 0 ) && m_outputDirValid );
}
