#include "errordialog.h"
#include <qlayout.h>
#include <qpushbutton.h>
#include <qtextbrowser.h>
#include <qapplication.h>

ErrorDialog::ErrorDialog ( const QStringList & errors, QWidget * parent, const char * name, WFlags flags )
	: QDialog ( parent, name, false, flags )
	, m_list ( NULL )
	, m_button ( NULL )
{
	setCaption ( "BIRT - Error Log" );
	
	// Create the layout
	QVBoxLayout * layout ( new QVBoxLayout ( this ) );
	layout->setMargin ( 5 );
	layout->setSpacing ( 5 );
	
	// Add the list of errors
	m_list = new QTextBrowser ( this );
	SetupErrorList ( errors );

	// Add the close button
	m_button = new QPushButton ( "Close", this );
	connect ( m_button, SIGNAL ( clicked ( ) ), this, SLOT ( accept ( ) ) );
	connect ( m_button, SIGNAL ( clicked ( ) ), this, SIGNAL ( Closing ( ) ) );

	// Add the widgets to the layout
	layout->addWidget ( m_list );
	layout->addWidget ( m_button );
}


void ErrorDialog::SetupErrorList ( const QStringList & errors )
{
	QTextBrowser & browser ( *( static_cast < QTextBrowser * > ( m_list ) ) );

	// Build up the text required, and get the longest line width
	QString longestLine;
	QString html ( "<qt>\n<body>\n<p>\nErrors encountered:\n</p>\n<ul>\n" );
	for ( QStringList::const_iterator position ( errors.constBegin ( ) ); position != errors.constEnd ( ); ++position )
	{
		html += "<li>" + *position + "</li>\n";
		if ( ( *position ).length ( ) > longestLine.length ( ) )
			longestLine = *position;
	}
	html += "</ul>\n</body>\n</qt>";

	// Update the browser
	browser.setText ( html );
	
	// Resize the browser as required
	QFontMetrics metric ( browser.fontMetrics ( ) );
	QSize newSize ( metric.width ( longestLine ) + browser.tabStopWidth ( ) + 8, metric.height ( ) * ( errors.size ( ) + 1 ) );
	QSize desktopSize ( QApplication::desktop ( )->width ( ), QApplication::desktop ( )->height ( ) );
	
	if ( newSize.width ( ) > ( desktopSize.width ( ) / 3 ) * 2 )
		newSize.setWidth ( ( desktopSize.width ( ) / 3 ) * 2 );
	if ( newSize.height ( ) > desktopSize.height ( ) / 2 )
		newSize.setHeight ( desktopSize.height ( ) / 2 );
	
	browser.setMinimumSize ( newSize );
}
