#include "filechooserbuttonswidget.h"
#include <qlayout.h>
#include <qpushbutton.h>
#include <qfiledialog.h>
#include <qdir.h>


FileChooserButtonsWidget::FileChooserButtonsWidget ( QWidget * parent, const char * name, WFlags flags )
	: QWidget ( parent, name, flags )
	, m_add ( NULL )
	, m_remove ( NULL )
	, m_formats ( )
{
	// Create a vertical layout, with everything top aligned
	QVBoxLayout * layout ( new QVBoxLayout ( this ) );
	layout->setAlignment ( Qt::AlignTop );
	layout->setMargin ( 0 );
	layout->setSpacing ( 5 );
	
	// Create the widget set, add them to the layout and then setup their signals
	m_add = new QPushButton ( "Add Files", this );
	m_remove = new QPushButton ( "Remove Files", this );

	layout->addWidget ( m_add );
	layout->addWidget ( m_remove );
	
	connect ( m_add, SIGNAL ( clicked ( ) ), this, SLOT ( AddFiles ( ) ) );
	connect ( m_remove, SIGNAL ( clicked ( ) ), this, SIGNAL ( RemoveFiles ( ) ) );
}


void FileChooserButtonsWidget::AddFiles ( )
{
	// Create the filter
	QString filter ( "Images (" );

	QStringList formats ( m_formats.GetImageFormats ( ) );
	for ( QStringList::const_iterator format ( formats.constBegin ( ) ); format != formats.constEnd ( ); ++format )
	{
		QStringList extensions ( m_formats.GetImageExtensions ( *format ) );
		for ( QStringList::const_iterator extension ( extensions.constBegin ( ) ); extension != extensions.constEnd ( ); ++extension )
		{
			filter += " *." + *extension;
			QString lower ( ( *extension ).lower ( ) ), upper ( ( *extension ).upper ( ) );
			if ( ( *extension ) != lower ) filter += " *." + lower;
			if ( ( *extension ) != upper ) filter += " *." + upper;
		}
	}

	filter += ";;All Files ( *.* * )";

	// Get the file list
	QStringList files ( QFileDialog::getOpenFileNames ( filter, QDir::current ( ).path ( ), this, NULL, "Select Image Files" ) );

	// Send a new files message if there are any files to add
	if ( files.size ( ) > 0 )
		emit ( NewFiles ( files ) );
}
