#include "filechooserwidget.h"
#include "filechooserbuttonswidget.h"
#include <qlistbox.h>
#include <qfiledialog.h>
#include <qlayout.h>
#include <qvaluestack.h>
		
FileChooserWidget::FileChooserWidget ( QWidget * parent, const char * name, WFlags flags )
	: QHBox ( parent, name, flags )
	, m_files ( NULL )
	, m_buttons ( NULL )
{
	setMargin ( 5 );
	setSpacing ( 5 );
	setFrameShape ( QFrame::GroupBoxPanel );
	setFrameShadow ( QFrame::Sunken );
	
	// Create the widget set and setup the signals
	m_files = new QListBox ( this );
	m_buttons = new FileChooserButtonsWidget ( this );

	static_cast < QListBox * > ( m_files )->setSelectionMode ( QListBox::Extended );

	connect ( m_buttons, SIGNAL ( NewFiles ( QStringList ) ), this, SLOT ( AddFiles ( QStringList ) ) );
	connect ( m_buttons, SIGNAL ( RemoveFiles ( ) ), this, SLOT ( RemoveFiles ( ) ) );
}


QStringList FileChooserWidget::GetFiles ( ) const
{
	QListBox & fileList ( * static_cast < QListBox * > ( m_files ) );
	
	unsigned int fileListSize ( fileList.count ( ) );
	QStringList selectedFiles;

	for ( unsigned int position ( 0 ); position < fileListSize; ++position )
		selectedFiles.append ( fileList.text ( position ) );

	return selectedFiles;
}


void FileChooserWidget::AddFiles ( QStringList newfiles)
{
	QListBox & fileList ( * static_cast < QListBox * > ( m_files ) );
	
	// Add the new filenames to the list, but only if they aren't already there
	for ( QStringList::const_iterator position ( newfiles.constBegin ( ) ); position != newfiles.constEnd ( ); ++position )
		if ( ! fileList.findItem ( *position, Qt::ExactMatch ) )
			fileList.insertItem ( *position );

	fileList.sort ( );

	emit ( SelectionChanged ( fileList.count ( ) ) );
}


void FileChooserWidget::RemoveFiles ( )
{
	QListBox & fileList ( * static_cast < QListBox * > ( m_files ) );
	
	// Build up a stack containing the indices of items for removal
	unsigned int fileListSize ( fileList.count ( ) );
	QValueStack < unsigned int > removedIndices;
	
	for ( unsigned int position ( 0 ); position < fileListSize; ++position )
		if ( fileList.isSelected ( position ) )
			removedIndices.push ( position );

	// Pop indices off the stack and remove them, delete the values 
	// from the highest index down
	while ( ! removedIndices.empty ( ) )
		fileList.removeItem ( removedIndices.pop ( ) );

	fileList.sort ( );

	emit ( SelectionChanged ( fileList.count ( ) ) );
}
