#include "imageformats.h"
#include <qimage.h>


// Extension map for formats with multiple common extensions
const char * g_typeExtMap [ ] =
{
	"jpeg=jpg;jpe;jif;jpeg",
	0
};


void LoadStringMap ( QDict < QStringList > & destination, const char * source [ ] )
{
	for ( const char * * typePtr ( source ); *typePtr != 0; ++typePtr )
	{
		QStringList keyAndValues ( QStringList::split ( '=', *typePtr ) );
		destination.insert ( keyAndValues [ 0 ], new QStringList ( QStringList::split ( ';', keyAndValues [ 1 ] ) ) );
	}
}


ImageFormats::ImageFormats ( )
	: m_extensions ( 13, false )
{
	// When the dictionary is destroyed, it should delete all values
	m_extensions.setAutoDelete ( true );
	
	// Load the type/extension data in to the type=>[ext, ...] map
	LoadStringMap ( m_extensions, g_typeExtMap );
}


ImageFormats::~ImageFormats ( )
{
}


QStringList ImageFormats::GetImageFormats ( ) const
{
	QStringList outputFormats ( QImage::outputFormatList ( ) );
	for ( QStringList::iterator position ( outputFormats.begin ( ) ); position != outputFormats.end ( ); ++position )
		*position = ( *position ).lower ( );
	return outputFormats;
}


bool ImageFormats::IsValidFormat ( const QString & type ) const
{
	QString lowerType ( type.lower ( ) );
	
	QStringList formats ( GetImageFormats ( ) );
	for ( QStringList::iterator position ( formats.begin ( ) ); position != formats.end ( ); ++position )
		if ( lowerType == *position )
			return true;
	return false;
}


QStringList ImageFormats::GetImageExtensions ( const QString & type ) const
{
	QStringList * extensions ( m_extensions [ type ] );
	if ( extensions )
		return *extensions;
	else
		if ( IsValidFormat ( type ) )
			return type;
		else
			return QStringList ( );
}
