#include "outputwidget.h"
#include <qlineedit.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qfiledialog.h>
#include <qdir.h>
		

OutputWidget::OutputWidget ( QWidget * parent, const char * name, WFlags flags )
	: QWidget ( parent, name, flags )
	, m_dir ( NULL )
	, m_dirChooser ( NULL )
{
	// Create the layout
	QHBoxLayout * layout ( new QHBoxLayout ( this ) );
	layout->setMargin ( 0 );
	layout->setSpacing ( 5 );

	// Add the line and the button
	m_dir = new QLineEdit ( "", this );
	m_dirChooser = new QPushButton ( "Browse", this );

	layout->addWidget ( new QLabel ( "Output dir : ", this ) );
	layout->addWidget ( m_dir );
	layout->addWidget ( m_dirChooser );

	// Set up signals
	connect ( m_dirChooser, SIGNAL ( clicked ( ) ), this, SLOT ( BrowseClicked ( ) ) );
	connect ( this, SIGNAL ( SetDirText ( const QString & ) ), m_dir, SLOT ( setText ( const QString & ) ) );
	connect ( m_dir, SIGNAL ( textChanged ( const QString & ) ), this, SIGNAL ( DirTextChanged ( const QString & ) ) );

	// Default the directory to the current working dir
	emit ( SetDirText ( QDir::current ( ).path ( ) ) );
}


QString OutputWidget::GetDirectory ( ) const
{
	return static_cast < QLineEdit * > ( m_dir )->text ( );
}


void OutputWidget::BrowseClicked ( )
{
	// Get the new output directory
	QString directory ( QFileDialog::getExistingDirectory ( static_cast < QLineEdit * > ( m_dir )->text ( ), this, NULL,
				                                            "Select Output Directory" ) );

	// Place Change the dir text to match this selection
	emit ( SetDirText ( directory ) );
}
