#include "resizewidget.h"
#include "configfile.h"
#include <qlayout.h>
#include <qlabel.h>
#include <qcheckbox.h>
#include <qvalidator.h>


ResizeWidget::ResizeWidget ( QWidget * parent, const char * name, WFlags flags )
	: QWidget ( parent, name, flags )
	, m_width ( NULL )
	, m_height ( NULL )
	, m_ratio ( NULL )
{
	// Create the layout
	QHBoxLayout * layout ( new QHBoxLayout ( this ) );

	layout->setSpacing ( 5 );

	// Create the width and height boxes and add them to the dimension layout
	m_width = new QLineEdit ( QString::number ( TheConfigFile ( ).NewImageSize ( ).width ( ), 10 ), this );
	m_height = new QLineEdit ( QString::number ( TheConfigFile ( ).NewImageSize ( ).height ( ), 10 ), this );

	m_width->setValidator ( new QIntValidator ( this ) );
	m_height->setValidator ( new QIntValidator ( this ) );
	
	layout->addWidget ( new QLabel ( "New Size : ", this ) );
	layout->addWidget ( m_width );
	layout->addWidget ( new QLabel ( "x", this ) );
	layout->addWidget ( m_height );

	// Create the ratio box
	m_ratio = new QComboBox ( false, this );
	m_ratio->insertItem ( "Ignore source ratio", IGNORE );
	m_ratio->insertItem ( "Match target width", KEEP_WIDTH );
	m_ratio->insertItem ( "Match target height", KEEP_HEIGHT );
	m_ratio->insertItem ( "Smart ratio match", SMART );
	m_ratio->setCurrentItem ( TheConfigFile ( ).NewImageRatioIndex ( ) );

	layout->addSpacing ( 32 );
	layout->addWidget ( m_ratio );
}


unsigned long ResizeWidget::Width ( ) const
{
	return ( static_cast < QLineEdit * > ( m_width )->text ( ) ).toULong ( );
}


unsigned long ResizeWidget::Height ( ) const
{
	return ( static_cast < QLineEdit * > ( m_height )->text ( ) ).toULong ( );
}


bool ResizeWidget::RatioIgnore ( ) const
{
	return m_ratio->currentItem ( ) == IGNORE;
}


bool ResizeWidget::RatioWidth ( ) const
{
	return m_ratio->currentItem ( ) == KEEP_WIDTH;
}


bool ResizeWidget::RatioHeight ( ) const
{
	return m_ratio->currentItem ( ) == KEEP_HEIGHT;
}

bool ResizeWidget::RatioSmart ( ) const
{
	return m_ratio->currentItem ( ) == SMART;
}
