#include "scalequalitywidget.h"
#include "configfile.h"
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qlayout.h>
#include <qlabel.h>


ScaleQualityWidget::ScaleQualityWidget ( QWidget * parent, const char * name, WFlags flags )
	: QWidget ( parent, name, flags )
	, m_fastScale ( NULL )
	, m_smoothScale ( NULL )
{
	// Create the layout
	QHBoxLayout * layout ( new QHBoxLayout ( this ) );
	layout->setAlignment ( Qt::AlignLeft );
	layout->setSpacing ( 5 );
	
	// Create the button group and add the options to it
	QButtonGroup * group ( new QButtonGroup ( this ) );
	group->setFrameShape ( QFrame::NoFrame );
	group->setFrameShadow ( QFrame::Plain );

	m_fastScale = new QRadioButton ( "Fast Scale", this );
	m_smoothScale = new QRadioButton ( "Smooth Scale", this );

	group->insert ( static_cast < QRadioButton * > ( m_fastScale ) );
	group->insert ( static_cast < QRadioButton * > ( m_smoothScale ) );

	// Add the buttons to the layout
	layout->addWidget ( new QLabel ( "Scale Quality : ", this ) );
	layout->addWidget ( m_fastScale );
	layout->addWidget ( m_smoothScale );

	// Default to the smooth scaling
	group->setButton ( group->id ( static_cast < QRadioButton * > ( TheConfigFile ( ).NewImageSmooth ( ) ? m_smoothScale : m_fastScale ) ) );

	// Build up the options lookup
	m_options.insert ( "fast", m_fastScale ); 
	m_options.insert ( "smooth", m_smoothScale );
}


bool ScaleQualityWidget::IsOptionSet ( const QString & option ) const
{
	QMap < QString, QWidget * >::const_iterator value ( m_options.find ( option.lower ( ) ) );
	if ( value != m_options.constEnd ( ) )
		return static_cast < QRadioButton * > ( *value )->isChecked ( );
	else
		return false;
}
